@@ -3,6 +3,8 @@ package common
 import (
 	"context"
 	"reflect"
+
+	"github.com/v2fly/v2ray-core/v5/common/registry"
 )
 
 // ConfigCreator is a function to create an object by a config.
@@ -17,6 +19,8 @@ func RegisterConfig(config interface{}, configCreator ConfigCreator) error {
 		return newError(configType.Name() + " is already registered").AtError()
 	}
 	typeCreatorRegistry[configType] = configCreator
+
+	registry.RegisterImplementation(config, nil)
 	return nil
 }
 
