@@ -1,6 +1,3 @@
-//go:build !confonly
-// +build !confonly
-
 package tls
 
 import (
@@ -12,9 +9,9 @@ import (
 	"sync"
 	"time"
 
-	"github.com/v2fly/v2ray-core/v4/common/net"
-	"github.com/v2fly/v2ray-core/v4/common/protocol/tls/cert"
-	"github.com/v2fly/v2ray-core/v4/transport/internet"
+	"github.com/v2fly/v2ray-core/v5/common/net"
+	"github.com/v2fly/v2ray-core/v5/common/protocol/tls/cert"
+	"github.com/v2fly/v2ray-core/v5/transport/internet"
 )
 
 var globalSessionCache = tls.NewLRUClientSessionCache(128)
@@ -36,32 +33,6 @@ func ParseCertificate(c *cert.Certificate) *Certificate {
 func (c *Config) loadSelfCertPool() (*x509.CertPool, error) {
 	root := x509.NewCertPool()
 	for _, cert := range c.Certificate {
-		/* Do not treat client certificate authority as a peer certificate authority.
-		   This is designed to prevent a client certificate with a permissive key usage from being used to attacker server.
-		   In next release, the certificate usage will be enforced strictly.
-		   Only a certificate with AUTHORITY_VERIFY usage will be accepted.
-		*/
-		if cert.Usage == Certificate_AUTHORITY_VERIFY_CLIENT {
-			continue
-		}
-		if !root.AppendCertsFromPEM(cert.Certificate) {
-			return nil, newError("failed to append cert").AtWarning()
-		}
-	}
-	return root, nil
-}
-
-func (c *Config) loadSelfCertPoolClientCA() (*x509.CertPool, error) {
-	root := x509.NewCertPool()
-	for _, cert := range c.Certificate {
-		/* Do not treat client certificate authority as a peer certificate authority.
-		   This is designed to prevent a client certificate with a permissive key usage from being used to attacker server.
-		   In next release, the certificate usage will be enforced strictly.
-		   Only a certificate with AUTHORITY_VERIFY usage will be accepted.
-		*/
-		if cert.Usage != Certificate_AUTHORITY_VERIFY_CLIENT {
-			continue
-		}
 		if !root.AppendCertsFromPEM(cert.Certificate) {
 			return nil, newError("failed to append cert").AtWarning()
 		}
@@ -228,11 +199,6 @@ func (c *Config) GetTLSConfig(opts ...Option) *tls.Config {
 		newError("failed to load system root certificate").AtError().Base(err).WriteToLog()
 	}
 
-	clientRoot, err := c.loadSelfCertPoolClientCA()
-	if err != nil {
-		newError("failed to load client root certificate").AtError().Base(err).WriteToLog()
-	}
-
 	if c == nil {
 		return &tls.Config{
 			ClientSessionCache:     globalSessionCache,
@@ -242,6 +208,7 @@ func (c *Config) GetTLSConfig(opts ...Option) *tls.Config {
 			SessionTicketsDisabled: true,
 		}
 	}
+
 	config := &tls.Config{
 		ClientSessionCache:     globalSessionCache,
 		RootCAs:                root,
@@ -249,15 +216,12 @@ func (c *Config) GetTLSConfig(opts ...Option) *tls.Config {
 		NextProtos:             c.NextProtocol,
 		SessionTicketsDisabled: !c.EnableSessionResumption,
 		VerifyPeerCertificate:  c.verifyPeerCert,
-		ClientCAs:              clientRoot,
 	}
 
 	for _, opt := range opts {
 		opt(config)
 	}
-	if c.VerifyClientCertificate {
-		config.ClientAuth = tls.RequireAndVerifyClientCert
-	}
+
 	config.Certificates = c.BuildCertificates()
 	config.BuildNameToCertificate()
 
